GitlabModel class

Constructors

GitlabModel({bool enabled = false, String? token, String? projectId, String? tag, String? host, String? ref})
GitlabModel.fromYaml(Map? yamlMap)
factory

Properties

enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
host → String?
final
projectId → String?
final
ref → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
final
token → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited