HooksConfigModel class

Top-level hooks configuration — holds all configured git hooks.

Constructors

HooksConfigModel({Map<String, HookModel>? hooks})
HooksConfigModel.fromYaml(Map yamlMap)
factory

Properties

enabledHooks Map<String, HookModel>
Returns only enabled hooks.
no setter
hashCode int
The hash code for this object.
no setterinherited
hooks Map<String, HookModel>
Map keyed by git hook name (e.g. pre-commit, pre-push).
final
isEmpty bool
no setter
isNotEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited