allowFailure property
If true, a failed step is marked as "warning" instead of "failure"
in the pipeline summary. Implies continue_on_error: true.
Defaults to false
Implementation
final bool allowFailure;
If true, a failed step is marked as "warning" instead of "failure"
in the pipeline summary. Implies continue_on_error: true.
Defaults to false
final bool allowFailure;