continueOnError property

bool continueOnError
final

If true, pipeline continues even if this step fails. The step is marked as failed in the summary but doesn't halt execution.

Defaults to false

Implementation

final bool continueOnError;