timeout property
Timeout in seconds. The step is killed if it exceeds this duration. Must be a positive integer when specified.
Implementation
final int? timeout;
Timeout in seconds. The step is killed if it exceeds this duration. Must be a positive integer when specified.
final int? timeout;