PipelineValidationError class

Validation result for a single issue found in pipeline configuration.

Constructors

PipelineValidationError({required String pipelineName, String? stepName, required String message, bool isWarning = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isWarning bool
final
message String
final
pipelineName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited