HookRunResult class

Result of running an entire hook.

Constructors

HookRunResult({required String hookName, required bool success, List<HookStepResult> stepResults = const [], required Duration totalDuration, String? pipelineRan})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hookName String
final
pipelineRan String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepResults List<HookStepResult>
final
success bool
final
totalDuration Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited