HookStepResult class

Result of running an individual hook step.

Constructors

HookStepResult({required String stepName, required bool passed, bool skipped = false, bool warned = false, required Duration duration, String? note})
const

Properties

duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
note → String?
final
passed → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipped → bool
final
stepName → String
final
warned → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited