models/app_config_model library

Classes

AppStoreModel
AWSModel
DiawiModel
FlutterReleaseXAppConfigModel
GithubModel
GitlabModel
GoogleDriveModel
PipelineConfigValidator
Validates pipeline configuration and returns actionable error messages.
PipelineModel
Represents a named pipeline containing a group of steps.
PipelineStepModel
PipelineValidationError
Validation result for a single issue found in pipeline configuration.
PlayStoreModel
QrCodeModel
SlackModel
TeamsModel
UploadOptionsModel