PipelineConfigValidator class
Validates pipeline configuration and returns actionable error messages.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
validate(
Map< String, PipelineModel> pipelines) → List<PipelineValidationError> - Validate all pipelines and return a list of issues found. Returns an empty list if everything is valid.