PipelineModel class
Represents a named pipeline containing a group of steps.
Pipelines allow users to organize multiple workflows (e.g., "build", "test", "deploy") and select which one to run.
Constructors
-
PipelineModel({required String name, String? description, required List<
PipelineStepModel> steps}) -
PipelineModel.fromYaml(String name, Map<
String, dynamic> yamlMap) -
factory
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
steps
→ List<
PipelineStepModel> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited