condition property
Shell command to evaluate before running this step. Step is only executed if this command exits with code 0. If the condition fails, the step is skipped (not failed).
Implementation
final String? condition;
Shell command to evaluate before running this step. Step is only executed if this command exits with code 0. If the condition fails, the step is skipped (not failed).
final String? condition;