continueOnError property
If true, pipeline continues even if this step fails.
The step is marked as failed in the summary but doesn't halt execution.
Defaults to false
Implementation
final bool continueOnError;
If true, pipeline continues even if this step fails.
The step is marked as failed in the summary but doesn't halt execution.
Defaults to false
final bool continueOnError;