PipelineValidationError class
Validation result for a single issue found in pipeline configuration.
Constructors
- PipelineValidationError({required String pipelineName, String? stepName, required String message, bool isWarning = false})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited